# Staples Removal

Detection and automatic deletion of staples in images of wound of abdominal surgery.

```
Munar, M., González-Hidalgo, M., & Moyà, G. (2019).
Final Degree Project 
Universitat de les Illes Balears
``` 

